Class: RuboCop::Cop::ParamHelp::ParameterTag
- Inherits:
-
Struct
- Object
- Struct
- RuboCop::Cop::ParamHelp::ParameterTag
- Defined in:
- lib/rubocop/cop/mixin/param_help.rb
Overview
"@param" tag with data from Yard and parsed source code
Instance Attribute Summary collapse
-
#desc_pos ⇒ Integer
Returns the value of attribute desc_pos.
-
#description_lines ⇒ Array<String>
Returns the value of attribute description_lines.
-
#name ⇒ String
Returns the value of attribute name.
-
#tag_range ⇒ Parser::Source::Range
Returns the value of attribute tag_range.
-
#tag_source_line ⇒ Parser::Source::Comment
Returns the value of attribute tag_source_line.
-
#type_pos ⇒ Integer
Returns the value of attribute type_pos.
-
#type_range ⇒ Parser::Source::Range
Returns the value of attribute type_range.
-
#types ⇒ Array<String>
Returns the value of attribute types.
-
#types_s ⇒ String
Returns the value of attribute types_s.
Instance Method Summary collapse
-
#description_opening ⇒ String?
First line of description, usually the part on the "@param" line.
Instance Attribute Details
#desc_pos ⇒ Integer
Returns the value of attribute desc_pos
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def desc_pos @desc_pos end |
#description_lines ⇒ Array<String>
Returns the value of attribute description_lines
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def description_lines @description_lines end |
#name ⇒ String
Returns the value of attribute name
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def name @name end |
#tag_range ⇒ Parser::Source::Range
Returns the value of attribute tag_range
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def tag_range @tag_range end |
#tag_source_line ⇒ Parser::Source::Comment
Returns the value of attribute tag_source_line
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def tag_source_line @tag_source_line end |
#type_pos ⇒ Integer
Returns the value of attribute type_pos
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def type_pos @type_pos end |
#type_range ⇒ Parser::Source::Range
Returns the value of attribute type_range
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def type_range @type_range end |
#types ⇒ Array<String>
Returns the value of attribute types
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def types @types end |
#types_s ⇒ String
Returns the value of attribute types_s
21 22 23 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 21 def types_s @types_s end |
Instance Method Details
#description_opening ⇒ String?
First line of description, usually the part on the "@param" line
29 30 31 |
# File 'lib/rubocop/cop/mixin/param_help.rb', line 29 def description_opening description_lines.first end |